@@ -100,6 +100,7 @@ def create_dynamic_openapi_tool(
 def discover_tools() -> Dict[str, Any]:
     """Discover tools from the tools directory"""
     tools = {}
+    failed_tools = []
 
     # Get the tools directory
     tools_dir = Path(__file__).parent / "tools"
@@ -143,15 +144,25 @@ def discover_tools() -> Dict[str, Any]:
                         "description": metadata.get("description", f"{tool_name} tool"),
                     }
                 except Exception as e:
+                    error_msg = str(e)
+                    # Track failed tools for summary
+                    failed_tools.append((tool_name, error_msg))
+                    
                     # Use stderr for stdio transport to avoid polluting JSON-RPC
                     if os.environ.get("MCP_TRANSPORT") == "stdio":
                         stderr_console.print(
-                            f"[yellow]Warning: Failed to load {tool_name}: {e}[/yellow]"
+                            f"[yellow]Warning: Failed to load {tool_name}: {error_msg}[/yellow]"
                         )
                     else:
-                        console.print(
-                            f"[yellow]Warning: Failed to load {tool_name}: {e}[/yellow]"
-                        )
+                        # Show concise message during discovery
+                        if "No module named" in error_msg:
+                            # Extract the missing module name
+                            missing_module = error_msg.split("'")[1] if "'" in error_msg else "unknown"
+                            console.print(f"[yellow]Warning: Failed to load {tool_name}: Missing dependency '{missing_module}'[/yellow]")
+                        else:
+                            console.print(
+                                f"[yellow]Warning: Failed to load {tool_name}: {error_msg}[/yellow]"
+                            )
     else:
         console.print(f"[red]Tools directory not found: {tools_dir}[/red]")
 
@@ -279,8 +290,8 @@ def hub(
 ):
     """Serve all tools on a single server with path-based routing using the hub"""
     # Get host and port from environment variables or defaults
-    serve_host = host or os.getenv("HOST", "127.0.0.1")
-    serve_port = port or int(os.getenv("PORT", "8000"))
+    serve_host = host or os.getenv("AUTOMAGIK_TOOLS_HOST", "127.0.0.1")
+    serve_port = port or int(os.getenv("AUTOMAGIK_TOOLS_SSE_PORT", "8884"))
 
     # For stdio transport, we can't serve multiple tools
     if transport == "stdio":
@@ -305,17 +316,17 @@ def hub(
 
         # Run the hub server
         if transport == "stdio":
-            hub_server.run(transport="stdio")
+            hub_server.run(transport="stdio", show_banner=False)
         elif transport == "http":
             console.print(
                 f"[green]🚀 Starting HTTP hub server on {serve_host}:{serve_port}[/green]"
             )
-            hub_server.run(transport="http", host=serve_host, port=serve_port)
+            hub_server.run(transport="http", host=serve_host, port=serve_port, show_banner=False)
         elif transport == "sse":
             console.print(
                 f"[green]🚀 Starting SSE hub server on {serve_host}:{serve_port}[/green]"
             )
-            hub_server.run(transport="sse", host=serve_host, port=serve_port)
+            hub_server.run(transport="sse", host=serve_host, port=serve_port, show_banner=False)
         else:
             console.print(f"[red]❌ Unsupported transport: {transport}[/red]")
             sys.exit(1)
@@ -344,7 +355,7 @@ def tool(
     """Serve a specific tool"""
     # Set transport early so discover_tools can use it
     os.environ["MCP_TRANSPORT"] = transport
-    
+
     tools = discover_tools()
 
     if tool_name not in tools:
@@ -357,8 +368,8 @@ def tool(
         sys.exit(1)
 
     # Get host and port from environment variables or defaults
-    serve_host = host or os.getenv("HOST", "127.0.0.1")
-    serve_port = port or int(os.getenv("PORT", "8000"))
+    serve_host = host or os.getenv("AUTOMAGIK_TOOLS_HOST", "127.0.0.1")
+    serve_port = port or int(os.getenv("AUTOMAGIK_TOOLS_SSE_PORT", "8884"))
 
     # Only print to console for non-stdio transports
     if transport != "stdio":
@@ -378,17 +389,17 @@ def tool(
         os.environ["MCP_TRANSPORT"] = transport
 
         if transport == "stdio":
-            mcp_server.run(transport="stdio")
+            mcp_server.run(transport="stdio", show_banner=False)
         elif transport == "sse":
             console.print(
                 f"[green]🚀 Starting SSE server on {serve_host}:{serve_port}[/green]"
             )
-            mcp_server.run(transport="sse", host=serve_host, port=serve_port)
+            mcp_server.run(transport="sse", host=serve_host, port=serve_port, show_banner=False)
         elif transport == "http":
             console.print(
                 f"[green]🚀 Starting HTTP server on {serve_host}:{serve_port}[/green]"
             )
-            mcp_server.run(transport="http", host=serve_host, port=serve_port)
+            mcp_server.run(transport="http", host=serve_host, port=serve_port, show_banner=False)
         else:
             console.print(f"[red]❌ Unsupported transport: {transport}[/red]")
             sys.exit(1)
@@ -405,10 +416,10 @@ def tool(
 def openapi(
     url: str = typer.Argument(..., help="OpenAPI specification URL"),
     host: Optional[str] = typer.Option(
-        None, help="Host to bind to (overrides HOST env var)"
+        None, help="Host to bind to (overrides AUTOMAGIK_TOOLS_HOST env var)"
     ),
     port: Optional[int] = typer.Option(
-        None, help="Port to bind to (overrides PORT env var)"
+        None, help="Port to bind to (overrides AUTOMAGIK_TOOLS_SSE_PORT env var)"
     ),
     transport: str = typer.Option(
         "stdio", "--transport", "-t", help="Transport type: stdio (default), http, sse"
@@ -431,24 +442,24 @@ def openapi(
         )
 
         # Get host and port
-        serve_host = host or os.getenv("HOST", "127.0.0.1")
-        serve_port = port or int(os.getenv("PORT", "8000"))
+        serve_host = host or os.getenv("AUTOMAGIK_TOOLS_HOST", "127.0.0.1")
+        serve_port = port or int(os.getenv("AUTOMAGIK_TOOLS_SSE_PORT", "8884"))
 
         # Start the server
         os.environ["MCP_TRANSPORT"] = transport
 
         if transport == "stdio":
-            mcp_server.run(transport="stdio")
+            mcp_server.run(transport="stdio", show_banner=False)
         elif transport == "sse":
             console.print(
                 f"[green]🚀 Starting SSE server on {serve_host}:{serve_port}[/green]"
             )
-            mcp_server.run(transport="sse", host=serve_host, port=serve_port)
+            mcp_server.run(transport="sse", host=serve_host, port=serve_port, show_banner=False)
         elif transport == "http":
             console.print(
                 f"[green]🚀 Starting HTTP server on {serve_host}:{serve_port}[/green]"
             )
-            mcp_server.run(transport="http", host=serve_host, port=serve_port)
+            mcp_server.run(transport="http", host=serve_host, port=serve_port, show_banner=False)
         else:
             console.print(f"[red]❌ Unsupported transport: {transport}[/red]")
             sys.exit(1)
